@@ -57,6 +57,9 @@ class MGMT_WEBAPP:
     KAFKA_MANAGER_SUBRESOURCE = "kafka-manager"
     KAFKA_SUBRESOURCE = "kafka"
     ELK_MANAGER_SUBRESOURCE = "elk-manager"
+    RYU_MANAGER_SUBRESOURCE = "ryu-manager"
+    RYU_CONTROLLER_SUBRESOURCE = "ryu-controller"
+    RYU_MONITOR_SUBRESOURCE = "ryu-monitor"
     ELK_STACK_SUBRESOURCE = "elk-stack"
     ELASTIC_SUBRESOURCE = "elastic"
     KIBANA_SUBRESOURCE = "kibana"
